% This program corresponds to Section 6.2.2 of the thesis.
% The effective rotational restraint contribution of a Euler-Bernoulli beam to the connected column is derived
% Note that this derivation uses the conjugate beam method, which is one of several possible different solution approaches
clc, clear, close all

% Obtain governing equations
syms x1 x2 x3 L1 L2 L3 L E I lb1 lb2 lb3 Mi Mj ti tj R0i R0j
C1 = Mi/(E*lb1*I)*(1 - x1/L)            -  Mj/(E*lb1*I)*(x1/L);
C2 = Mi/(E*lb2*I)*(1 - L1/L - x2/L)       -  Mj/(E*lb2*I)*(L1/L + x2/L);
C3 = Mi/(E*lb3*I)*(1 - L1/L - L2/L - x3/L)  -  Mj/(E*lb3*I)*(L1/L + L2/L + x3/L);
A1 = int(C1,x1,0,L1);
A2 = int(C2,x2,0,L2);
A3 = int(C3,x3,0,L3);
A = A1 + A2 + A3;
a1A1 = int(x1*C1,x1,0,L1);
a2A2 = int(x2*C2,x2,0,L2);
a3A3 = int(x3*C3,x3,0,L3);
a1 = a1A1/A1;
a2 = a2A2/A2  +  L1;
a3 = a3A3/A3  +  L1  +  L2;
a_bar = (a1*A1 + a2*A2 + a3*A3)/A;
b_bar = L  -  a_bar;
eqn1 = ti  -  Mi/R0i  -  A*b_bar/L == 0;
eqn2 = tj  -  Mj/R0j  +  A*a_bar/L == 0;
eqn3 = L1 + L2 + L3 - L == 0;

% Solve the system of equations for the end moments
syms ri rj Ti Tj
eqn1 = subs(eqn1, R0i, 3*E*I*ri/(L*Ti*(1 - ri)) );
eqn2 = subs(eqn2, R0j, 3*E*I*rj/(L*Tj*(1 - rj)) );
X = solve([eqn1,eqn2,eqn3],[Mi,Mj,L]);
simplify(X.Mi)
simplify(X.Mj)

% Simplify X.Mi and X.Mj by hand to obtain the following solution:
syms ljj lii lij lji lA lB lC lD
ci1 = 1*(L1^4*lb2*lb3 + L2^4*lb1*lb3 + L3^4*lb1*lb2)/L^4;
ci2 = 3*(L1*L2^3*lb2*lb3 + L1*L3^3*lb2*lb3 + L2*L3^3*lb1*lb3)/L^4;
ci3 = 4*(L2*L1^3*lb2*lb3 + L3*L1^3*lb2*lb3 + L3*L2^3*lb1*lb3)/L^4;
ci4 = 1*(L1*L2^3*lb1*lb3 + L1*L3^3*lb1*lb2 + L2*L3^3*lb1*lb2)/L^4;
ci5 = 6*(L1^2*L2^2*lb2*lb3 + L1^2*L3^2*lb2*lb3 + L2^2*L3^2*lb1*lb3)/L^4;
ci6 = 9*(L1*L2^2*L3*lb2*lb3 + L1*L2*L3^2*lb2*lb3)/L^4;
ci7 = 12*(L1^2*L2*L3*lb2*lb3)/L^4;
ci8 = 3*(L1*L2^2*L3*lb1*lb3 + L1*L2*L3^2*lb1*lb3)/L^4;
cj1 = 1*(L1^4*lb2*lb3 + L2^4*lb1*lb3 + L3^4*lb1*lb2)/L^4;
cj2 = 3*(L2*L1^3*lb1*lb3 + L3*L1^3*lb1*lb2 + L3*L2^3*lb1*lb2)/L^4;
cj3 = 4*(L1*L2^3*lb1*lb3 + L1*L3^3*lb1*lb2 + L2*L3^3*lb1*lb2)/L^4;
cj4 = 1*(L2*L1^3*lb2*lb3 + L3*L1^3*lb2*lb3 + L3*L2^3*lb1*lb3)/L^4;
cj5 = 6*(L1^2*L2^2*lb1*lb3 + L1^2*L3^2*lb1*lb2 + L2^2*L3^2*lb1*lb2)/L^4;
cj6 = 9*(L1^2*L2*L3*lb1*lb2 + L1*L2^2*L3*lb1*lb2)/L^4;
cj7 = 12*(L1*L2*L3^2*lb1*lb2)/L^4;
cj8 = 3*(L1^2*L2*L3*lb1*lb3 + L1*L2^2*L3*lb1*lb3)/L^4;
sumci = ci1 + ci2 + ci3 + ci4 + ci5 + ci6 + ci7 + ci8;
sumcj = cj1 + cj2 + cj3 + cj4 + cj5 + cj6 + cj7 + cj8;
lii = 1/L^3*(L1^3*lb2*lb3 + L2^3*lb1*lb3 + L3^3*lb1*lb2  +  ...
             3*L1*L2^2*lb1*lb3 + 3*L1*L3^2*lb1*lb2 + 3*L2*L1^2*lb1*lb3 + ...
             3*L2*L3^2*lb1*lb2 + 3*L3*L1^2*lb1*lb2 + 3*L3*L2^2*lb1*lb2 + ...
             6*L1*L2*L3*lb1*lb2);
lij = 1/L^3*(L1^3*lb2*lb3 + L2^3*lb1*lb3 + L3^3*lb1*lb2  +  ...
             3*L1*L2^2*lb1*lb3 + 3*L1*L3^2*lb1*lb2 + 3*L2*L1^2*lb2*lb3 + ...
             3*L2*L3^2*lb1*lb2 + 3*L3*L1^2*lb2*lb3 + 3*L3*L2^2*lb1*lb3 + ...
             6*L1*L2*L3*lb1*lb3);
lji = lij;
ljj = 1/L^3*(L1^3*lb2*lb3 + L2^3*lb1*lb3 + L3^3*lb1*lb2  +  ...
             3*L1*L2^2*lb2*lb3 + 3*L1*L3^2*lb2*lb3 + 3*L2*L1^2*lb2*lb3 + ...
             3*L2*L3^2*lb1*lb3 + 3*L3*L1^2*lb2*lb3 + 3*L3*L2^2*lb1*lb3 + ...
             6*L1*L2*L3*lb2*lb3);
gi = Tj*lb1*lb2*lb3*(1 - rj)  +  rj*lii;
gj = Ti*lb1*lb2*lb3*(1 - ri)  +  ri*ljj;
lA = lb1*lb2*lb3*Ti*Tj; 
lB = 4*Tj*(sumci-Ti*lb1*lb2*lb3);
lC = 4*Ti*(sumcj-Tj*lb1*lb2*lb3);
lD = 4*(Tj*sumci + Ti*sumcj - Ti*Tj*lb1*lb2*lb3) -...
      3/L^4*(L1^4*lb2*lb3/lb1 + L2^4*lb1*lb3/lb2 + L3^4*lb1*lb2/lb3 + ...
            4*L1*L2^3*lb3 + 4*L1*L3^3*lb2 + 4*L2*L1^3*lb3 + ...
            4*L2*L3^3*lb1 + 4*L3*L1^3*lb2 + 4*L3*L2^3*lb1 + ...
            6*L1^2*L2^2*lb3 + 6*L1^2*L3^2*lb2 + 6*L2^2*L3^2*lb1 + ...
            12*L1^2*L2*L3*lb2 + 12*L1*L2^2*L3*lb2 + 12*L1*L2*L3^2*lb2);
Mi_s = 6*E*I/L*(ri)/(4*lA  +  ri*lB  +  rj*lC  -  ri*rj*lD)*(2*gi*ti  +  lij*rj*tj);
Mj_s = 6*E*I/L*(rj)/(4*lA  +  ri*lB  +  rj*lC  -  ri*rj*lD)*(2*gj*tj  +  lji*ri*ti);
M_s = [Mi_s, Mj_s];
M_s = subs(M_s, L, L1 + L2 + L3);

% Verify the correctness of the hand-simplified solution
simplify(M_s(1)  -  X.Mi) % = 0
simplify(M_s(2)  -  X.Mj) % = 0